@@ -14,16 +14,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
 #include <string.h>
 #include <stdio.h> /* Early versions of bzlib (1.0) require stdio.h */
-#include <bzlib.h>
 
 #include "gpg.h"
-#include "util.h"
+#include "../common/util.h"
+#include <bzlib.h>
+
 #include "packet.h"
 #include "filter.h"
 #include "main.h"
@@ -156,7 +157,7 @@ do_uncompress( compress_filter_context_t *zfx, bz_stream *bzs,
 	rc = -1; /* eof */
       else if( zrc != BZ_OK && zrc != BZ_PARAM_ERROR )
 	log_fatal("bz2lib inflate problem: rc=%d\n", zrc );
-      else if (zrc == BZ_OK && eofseen 
+      else if (zrc == BZ_OK && eofseen
                && !bzs->avail_in && bzs->avail_out > 0)
         {
           log_error ("unexpected EOF in bz2lib\n");
@@ -248,6 +249,6 @@ compress_filter_bz2( void *opaque, int control,
 	zfx->release (zfx);
     }
   else if( control == IOBUFCTRL_DESC )
-    *(char**)buf = "compress_filter";
+    mem2str (buf, "compress_filter", *ret_len);
   return rc;
 }
