@@ -14,17 +14,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 /* This is a simple stand-alone Assuan server test program.  We don't
    want to use the assuan library because we don't want to hide errors
-   in that library. 
+   in that library.
 
    The script language is line based.  Empty lines or lines containing
    only white spaces are ignored, line with a hash sign as first non
    white space character are treated as comments.
-   
+
    A simple macro mechanism is implemnted.  Macros are expanded before
    a line is processed but after comment processing.  Macros are only
    expanded once and non existing macros expand to the empty string.
@@ -79,7 +79,7 @@
       is ignored.
 
    count-status <code>
-      Initialize the assigned variable to 0 and assign it as an counter for 
+      Initialize the assigned variable to 0 and assign it as an counter for
       status code CODE.  This command must be called with an assignment.
 
    quit
@@ -199,7 +199,10 @@ die (const char *format, ...)
   exit (1);
 }
 
-#define die(format, args...) (die) ("%s: " format, __func__ , ##args)
+#define die_0(format)          (die) ("%s: " format, __func__)
+#define die_1(format, a)       (die) ("%s: " format, __func__, (a))
+#define die_2(format, a, b)    (die) ("%s: " format, __func__, (a),(b))
+#define die_3(format, a, b, c) (die) ("%s: " format, __func__, (a),(b),(c))
 
 static void
 err (const char *format, ...)
@@ -249,7 +252,7 @@ writen (int fd, const char *buffer, size_t length)
   while (length)
     {
       int nwritten = write (fd, buffer, length);
-      
+
       if (nwritten < 0)
         {
           if (errno == EINTR)
@@ -290,7 +293,7 @@ read_assuan (int fd)
       if (pending_len)
         {
           if (pending_len >= nleft)
-            die ("received line too large");
+            die_0 ("received line too large");
           memcpy (buf, pending, pending_len);
           n = pending_len;
           pending_len = 0;
@@ -303,7 +306,7 @@ read_assuan (int fd)
             }
           while (n < 0 && errno == EINTR);
         }
-      
+
       if (opt_verbose && n >= 0 )
 	{
 	  int i;
@@ -315,13 +318,13 @@ read_assuan (int fd)
 	}
 
       if (n < 0)
-        die ("reading fd %d failed: %s", fd, strerror (errno));
+        die_2 ("reading fd %d failed: %s", fd, strerror (errno));
       else if (!n)
-        die ("received incomplete line on fd %d", fd);
+        die_1 ("received incomplete line on fd %d", fd);
       p = buf;
       nleft -= n;
       buf += n;
-      
+
       for (; n && *p != '\n'; n--, p++)
         ;
       if (n)
@@ -337,7 +340,7 @@ read_assuan (int fd)
         }
     }
   if (!nleft)
-    die ("received line too large");
+    die_0 ("received line too large");
 
   p = recv_line;
   if (p[0] == 'O' && p[1] == 'K' && (p[2] == ' ' || !p[2]))
@@ -366,8 +369,8 @@ read_assuan (int fd)
       recv_type = LINE_END;
       p += 3;
     }
-  else 
-    die ("invalid line type (%.5s)", p);
+  else
+    die_1 ("invalid line type (%.5s)", p);
 
   return p;
 }
@@ -381,13 +384,13 @@ write_assuan (int fd, const char *line)
   size_t n = strlen (line);
 
   if (n > 1024)
-    die ("line too long for Assuan protocol");
+    die_0 ("line too long for Assuan protocol");
   strcpy (buffer, line);
   if (!n || buffer[n-1] != '\n')
     buffer[n++] = '\n';
 
   if (writen (fd, buffer, n))
-      die ("sending line (\"%s\") to %d failed: %s", buffer, fd,
+      die_3 ("sending line (\"%s\") to %d failed: %s", buffer, fd,
 	   strerror (errno));
 }
 
@@ -404,15 +407,15 @@ start_server (const char *pgmname)
   pid_t pid;
 
   if (pipe (rp) < 0)
-    die ("pipe creation failed: %s", strerror (errno));
+    die_1 ("pipe creation failed: %s", strerror (errno));
   if (pipe (wp) < 0)
-    die ("pipe creation failed: %s", strerror (errno));
+    die_1 ("pipe creation failed: %s", strerror (errno));
 
   fflush (stdout);
   fflush (stderr);
   pid = fork ();
   if (pid < 0)
-    die ("fork failed");
+    die_0 ("fork failed");
 
   if (!pid)
     {
@@ -427,29 +430,29 @@ start_server (const char *pgmname)
       if (wp[0] != STDIN_FILENO)
         {
           if (dup2 (wp[0], STDIN_FILENO) == -1)
-              die ("dup2 failed in child: %s", strerror (errno));
+            die_1 ("dup2 failed in child: %s", strerror (errno));
           close (wp[0]);
         }
       if (rp[1] != STDOUT_FILENO)
         {
           if (dup2 (rp[1], STDOUT_FILENO) == -1)
-              die ("dup2 failed in child: %s", strerror (errno));
+            die_1 ("dup2 failed in child: %s", strerror (errno));
           close (rp[1]);
         }
       if (!opt_verbose)
         {
 	  int fd = open ("/dev/null", O_WRONLY);
 	  if (fd == -1)
-	    die ("can't open `/dev/null': %s", strerror (errno));
+	    die_1 ("can't open '/dev/null': %s", strerror (errno));
           if (dup2 (fd, STDERR_FILENO) == -1)
-            die ("dup2 failed in child: %s", strerror (errno));
+            die_1 ("dup2 failed in child: %s", strerror (errno));
 	  close (fd);
         }
 
       close (wp[1]);
       close (rp[0]);
-      execl (pgmname, arg0, "--server", NULL); 
-      die ("exec failed for `%s': %s", pgmname, strerror (errno));
+      execl (pgmname, arg0, "--server", NULL);
+      die_2 ("exec failed for '%s': %s", pgmname, strerror (errno));
     }
   close (wp[0]);
   close (rp[1]);
@@ -458,7 +461,7 @@ start_server (const char *pgmname)
 
   read_assuan (server_recv_fd);
   if (recv_type != LINE_OK)
-    die ("no greating message");
+    die_0 ("no greating message");
 }
 
 
@@ -476,7 +479,7 @@ unset_var (const char *name)
     ;
   if (!var)
     return;
-/*    fprintf (stderr, "unsetting `%s'\n", name); */
+/*    fprintf (stderr, "unsetting '%s'\n", name); */
 
   if (var->type == VARTYPE_FD && var->value)
     {
@@ -500,7 +503,7 @@ set_type_var (const char *name, const char *value, VARTYPE type)
   VARIABLE var;
 
   if (!name)
-    name = "?"; 
+    name = "?";
   for (var=variable_list; var && strcmp (var->name, name); var = var->next)
     ;
   if (!var)
@@ -511,7 +514,10 @@ set_type_var (const char *name, const char *value, VARTYPE type)
       variable_list = var;
     }
   else
-    free (var->value);
+    {
+      free (var->value);
+      var->value = NULL;
+    }
 
   if (var->type == VARTYPE_FD && var->value)
     {
@@ -521,7 +527,7 @@ set_type_var (const char *name, const char *value, VARTYPE type)
       if (fd != -1 && fd != 0 && fd != 1 && fd != 2)
           close (fd);
     }
-  
+
   var->type = type;
   var->count = 0;
   if (var->type == VARTYPE_COUNTER)
@@ -595,7 +601,7 @@ expand_line (char *buffer)
       p = strchr (line, '$');
       if (!p)
         return result; /* nothing more to expand */
-      
+
       if (p[1] == '$') /* quoted */
         {
           memmove (p, p+1, strlen (p+1)+1);
@@ -647,7 +653,7 @@ expand_line (char *buffer)
 
 
 /* Evaluate COND and return the result. */
-static int 
+static int
 eval_boolean (const char *cond)
 {
   int true = 1;
@@ -683,8 +689,8 @@ cmd_send (const char *assign_to, char *arg)
 {
   (void)assign_to;
   if (opt_verbose)
-    fprintf (stderr, "sending `%s'\n", arg);
-  write_assuan (server_send_fd, arg); 
+    fprintf (stderr, "sending '%s'\n", arg);
+  write_assuan (server_send_fd, arg);
 }
 
 static void
@@ -717,13 +723,13 @@ cmd_expect_ok (const char *assign_to, char *arg)
     {
       char *p = read_assuan (server_recv_fd);
       if (opt_verbose > 1)
-        fprintf (stderr, "got line `%s'\n", recv_line);
+        fprintf (stderr, "got line '%s'\n", recv_line);
       if (recv_type == LINE_STAT)
         handle_status_line (p);
     }
   while (recv_type != LINE_OK && recv_type != LINE_ERR);
   if (recv_type != LINE_OK)
-    die ("expected OK but got `%s'", recv_line);
+    die_1 ("expected OK but got '%s'", recv_line);
 }
 
 static void
@@ -738,13 +744,13 @@ cmd_expect_err (const char *assign_to, char *arg)
     {
       char *p = read_assuan (server_recv_fd);
       if (opt_verbose > 1)
-        fprintf (stderr, "got line `%s'\n", recv_line);
+        fprintf (stderr, "got line '%s'\n", recv_line);
       if (recv_type == LINE_STAT)
         handle_status_line (p);
     }
   while (recv_type != LINE_OK && recv_type != LINE_ERR);
   if (recv_type != LINE_ERR)
-    die ("expected ERR but got `%s'", recv_line);
+    die_1 ("expected ERR but got '%s'", recv_line);
 }
 
 static void
@@ -753,7 +759,7 @@ cmd_count_status (const char *assign_to, char *arg)
   char *p;
 
   if (!*assign_to || !*arg)
-    die ("syntax error: count-status requires an argument and a variable");
+    die_0 ("syntax error: count-status requires an argument and a variable");
 
   for (p=arg; *p && !spacep (p); p++)
     ;
@@ -762,7 +768,7 @@ cmd_count_status (const char *assign_to, char *arg)
       for (*p++ = 0; spacep (p); p++)
         ;
       if (*p)
-        die ("cmpfiles: syntax error");
+        die_0 ("cmpfiles: syntax error");
     }
   set_type_var (assign_to, arg, VARTYPE_COUNTER);
 }
@@ -773,12 +779,12 @@ cmd_openfile (const char *assign_to, char *arg)
   int fd;
   char numbuf[20];
 
-  do 
+  do
     fd = open (arg, O_RDONLY);
   while (fd == -1 && errno == EINTR);
   if (fd == -1)
-    die ("error opening `%s': %s", arg, strerror (errno));
-  
+    die_2 ("error opening '%s': %s", arg, strerror (errno));
+
   sprintf (numbuf, "%d", fd);
   set_type_var (assign_to, numbuf, VARTYPE_FD);
 }
@@ -789,11 +795,11 @@ cmd_createfile (const char *assign_to, char *arg)
   int fd;
   char numbuf[20];
 
-  do 
+  do
     fd = open (arg, O_WRONLY|O_CREAT|O_TRUNC, 0666);
   while (fd == -1 && errno == EINTR);
   if (fd == -1)
-    die ("error creating `%s': %s", arg, strerror (errno));
+    die_2 ("error creating '%s': %s", arg, strerror (errno));
 
   sprintf (numbuf, "%d", fd);
   set_type_var (assign_to, numbuf, VARTYPE_FD);
@@ -806,7 +812,7 @@ cmd_pipeserver (const char *assign_to, char *arg)
   (void)assign_to;
 
   if (!*arg)
-    die ("syntax error: servername missing");
+    die_0 ("syntax error: servername missing");
 
   start_server (arg);
 }
@@ -842,11 +848,11 @@ cmd_cmpfiles (const char *assign_to, char *arg)
   size_t nread1, nread2;
   int rc = 0;
 
-  set_var (assign_to, "0"); 
+  set_var (assign_to, "0");
   for (p=arg; *p && !spacep (p); p++)
     ;
   if (!*p)
-    die ("cmpfiles: syntax error");
+    die_0 ("cmpfiles: syntax error");
   for (*p++ = 0; spacep (p); p++)
     ;
   second = p;
@@ -857,19 +863,19 @@ cmd_cmpfiles (const char *assign_to, char *arg)
       for (*p++ = 0; spacep (p); p++)
         ;
       if (*p)
-        die ("cmpfiles: syntax error");
+        die_0 ("cmpfiles: syntax error");
     }
-  
+
   fp1 = fopen (arg, "rb");
   if (!fp1)
     {
-      err ("can't open `%s': %s", arg, strerror (errno));
+      err ("can't open '%s': %s", arg, strerror (errno));
       return;
     }
   fp2 = fopen (second, "rb");
   if (!fp2)
     {
-      err ("can't open `%s': %s", second, strerror (errno));
+      err ("can't open '%s': %s", second, strerror (errno));
       fclose (fp1);
       return;
     }
@@ -890,7 +896,7 @@ cmd_cmpfiles (const char *assign_to, char *arg)
     {
       if (opt_verbose)
         err ("files match");
-      set_var (assign_to, "1"); 
+      set_var (assign_to, "1");
     }
   else if (!rc)
     err ("cmpfiles: read error: %s", strerror (errno));
@@ -973,7 +979,7 @@ interpreter (char *line)
         assign_to = line;
     }
   if (!*line)
-    die ("syntax error");
+    die_0 ("syntax error");
   stmt = line;
   save_c = 0;
   save_p = NULL;
@@ -1003,7 +1009,7 @@ interpreter (char *line)
   if (!cmdtbl[i].name)
     {
       if (!assign_to)
-        die ("invalid statement `%s'\n", stmt);
+        die_1 ("invalid statement '%s'\n", stmt);
       if (save_p)
         *save_p = save_c;
       set_var (assign_to, stmt);
@@ -1078,7 +1084,7 @@ main (int argc, char **argv)
     {
       p = strchr (buffer,'\n');
       if (!p)
-        die ("incomplete script line");
+        die_0 ("incomplete script line");
       *p = 0;
       if (interpreter (buffer))
         break;
@@ -1086,4 +1092,3 @@ main (int argc, char **argv)
     }
   return 0;
 }
-
